@@ -18,7 +18,7 @@ class InterCache(object):
             result[i] = self.get(i)
         return result
 
-    get_multi = get_list
+    get_multi = get_dict
 
     def set(self, k, v):
         self.cache[k] = v
